@@ -120,13 +120,13 @@ class Client(http.HTTPClient):
         return self.put(url, body=body, headers=self.headers).json()
 
     @decorator.refresh_jwt_token
-    def create_scaler(self, cloud_id, body):
+    def create_scaler(self, cloud_id, body, **kwargs):
         """Create a scaler belong to a cloud.
 
         :param cloud_id: The id of cloud.
         :param body: A dictionary object.
         """
-        url = utils.generate_url('/scalers', cloud_id)
+        url = utils.generate_url('/scalers', cloud_id, **kwargs)
         return self.post(url, body=body, headers=self.headers).json()
 
     @decorator.refresh_jwt_token
@@ -279,13 +279,13 @@ class Client(http.HTTPClient):
         return self.delete(url, headers=self.headers, body=body).json()
 
     @decorator.refresh_jwt_token
-    def create_scheduler(self, cloud_id, body):
+    def create_scheduler(self, cloud_id, body, **kwargs):
         """Create a scheduler belong to a cloud.
 
         :param cloud_id: The id of cloud.
         :param body: A dictionary object.
         """
-        url = utils.generate_url('/schedulers', cloud_id)
+        url = utils.generate_url('/schedulers', cloud_id, **kwargs)
         return self.post(url, body=body, headers=self.headers).json()
 
     @decorator.refresh_jwt_token
@@ -320,14 +320,14 @@ class Client(http.HTTPClient):
         return self.put(url, body=body, headers=self.headers).json()
 
     @decorator.refresh_jwt_token
-    def bulk_create(self, cloud_id, body):
+    def bulk_create(self, cloud_id, body, **kwargs):
         """Create multiple workers belong to a cloud.
         Currently, supports Scheduler and Scaler
 
         :param cloud_id: The id of cloud.
         :param body: A dictionary object.
         """
-        url = utils.generate_url('/bulk_create', cloud_id)
+        url = utils.generate_url('/bulk_create', cloud_id, **kwargs)
         return self.post(url, body=body, headers=self.headers).json()
 
     @decorator.refresh_jwt_token
